## [Installation](#get-started)

## Alpha releases
Within a terminal run the command 
```
pip install --extra-index-url https://test.pypi.org/simple/ project-visualization-tool-GDeLuisi
```  

## Stable and test releases
Within a terminal run the command 
```
pip install project-visualization-tool-GDeLuisi
```


